Name:		mmseq
Version:	1.0.8a
Release:	27%{?dist}
Summary:	Haplotype and isoform specific expression estimation for RNA-seq

Group:		Applications/Engineering
License:	GPLv2+
URL:		https://github.com/eturro/%{name}
Source0:	https://github.com/eturro/%{name}/archive/%{version}.zip
Patch0:		mmseq-sam-header.patch
#Patch1:		mmseq-flags.patch
Patch2:		mmseq-zlib.patch
Patch3:		mmseq-iostream-c++11.patch
Patch4:		mmseq-static-data-members-initialization-c++11.patch

BuildRequires:  gcc-c++
BuildRequires:	boost-devel
BuildRequires:	perl-generators
BuildRequires:	samtools-devel
BuildRequires:	gsl-devel
BuildRequires:	zlib-devel
BuildRequires:	armadillo-devel

Requires:	ruby
Requires:	samtools
Requires:	perl-interpreter

%description
Software for fast, scalable haplotype and isoform expression
estimation using multi-mapping RNA-seq reads.  Example scripts are included.

%prep
%setup -q -n %{name}-%{version}
#Look for samtools headers in the correct location for Fedora
%patch0 -p1 -b .mmseq-sam-header.patch
#Use Fedora compilation headers
#%%patch1 -p1 -b .mmseq-flags.patch
#Fix zlib linking
%patch2 -p1 -b .mmseq-zlib.patch

# Apply c++11 patches for gcc >= 6
%if 0%{?fedora} >= 24
#Fix for C++11 iostream changes
%patch3 -p1 -b .mmseq-iostream-c++11.patch
#Fix for C++11 static data member initialization changes
%patch4 -p1 -b .mmseq-static-data-members-initialization-c++11.patch
%endif

#Remove bundled binaries
rm bin/*-linux
rm bin/*-mac

%build
cd src
make %{?_smp_mflags} CXXFLAGS="%{optflags}"


%install
rm -rf %{buildroot}

mkdir -p %{buildroot}%{_bindir}
install -p -m 0755 bin/bam2hits %{buildroot}%{_bindir}
install -p -m 0755 bin/extract_transcripts %{buildroot}%{_bindir}
install -p -m 0755 bin/hitstools %{buildroot}%{_bindir}
install -p -m 0755 bin/mmcollapse %{buildroot}%{_bindir}
install -p -m 0755 bin/mmdiff %{buildroot}%{_bindir}
install -p -m 0755 bin/mmseq %{buildroot}%{_bindir}
install -p -m 0755 bin/offsetGTF %{buildroot}%{_bindir}
install -p -m 0755 bin/t2g_hits %{buildroot}%{_bindir}
install -p -m 0755 bin/*.sh %{buildroot}%{_bindir}
install -p -m 0755 bin/*.rb %{buildroot}%{_bindir}
install -p -m 0755 bin/ensembl_gtf_to_gff.pl %{buildroot}%{_bindir}



%files
%doc README.md COPYING doc/
%{_bindir}/bam2hits
%{_bindir}/extract_transcripts
%{_bindir}/hitstools
%{_bindir}/mmcollapse
%{_bindir}/mmdiff
%{_bindir}/mmseq
%{_bindir}/offsetGTF
%{_bindir}/t2g_hits
%{_bindir}/fastagrep.sh
%{_bindir}/mouse_strain_transcriptome.sh
%{_bindir}/usage.sh
%{_bindir}/filterGTF.rb
%{_bindir}/haploref.rb
%{_bindir}/testregexp.rb
%{_bindir}/ensembl_gtf_to_gff.pl


%changelog
* Fri Aug 17 2018 José Abílio Matos <jamatos@fc.up.pt> - 1.0.8a-27
- rebuild for armadillo soname bump

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8a-26
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8a-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 23 2018 Jonathan Wakely <jwakely@redhat.com> - 1.0.8a-24
- Rebuilt for Boost 1.66

* Fri Sep 22 2017 Adam Huffman <bloch@verdurin.com> - 1.0.8a-23
- rebuilt for armadillo

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8a-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8a-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 24 2017 Björn Esser <besser82@fedoraproject.org> - 1.0.8a-20
- Rebuilt for Boost 1.64

* Thu Jul 13 2017 Petr Pisar <ppisar@redhat.com> - 1.0.8a-19
- perl dependency renamed to perl-interpreter
  <https://fedoraproject.org/wiki/Changes/perl_Package_to_Install_Core_Modules>

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.8a-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8a-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 1.0.8a-16
- Rebuilt for Boost 1.63

* Thu Jun 30 2016 José Matos <jamatos@fedoraproject.org> - 1.0.8a-15
- Rebuild for armadillo 7.x and remove BR SuperLU because armadillo takes care of that

* Sat Jun  4 2016 José Matos <jamatos@fedoraproject.org> - 1.0.8a-14
- Rebuild for armadillo 7.x

* Mon May 23 2016 Jonathan Wakely <jwakely@redhat.com> - 1.0.8a-13
- Add missing BuildRequires (#1337966)

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> - 1.0.8a-13
- Rebuilt for linker errors in boost (#1331983)

* Thu Feb 25 2016 José Matos <jamatos@fedoraproject.org> - 1.0.8a-12
- Apply the c++11 patches only to Fedora >= 24 (where g++ implements gnu++14)

* Mon Feb 22 2016 Orion Poplawski <orion@cora.nwra.com> - 1.0.8a-11
- Rebuild for gsl 2.1

* Fri Feb 12 2016 Adam Huffman <bloch@verdurin.com> - 1.0.8a-10
- patch to add compatibility with C++11 iostream
- patch to add compatibility with C++11 static data member initialization

* Wed Feb 10 2016 Adam Huffman <bloch@verdurin.com> - 1.0.8a-9
- rebuilt to pick up new armadillo

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8a-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 1.0.8a-7
- Rebuilt for Boost 1.60

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 1.0.8a-6
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.8a-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 1.0.8a-4
- rebuild for Boost 1.58

* Sun Jul 05 2015 Adam Huffman <bloch@verdurin.com> - 1.0.8a-3
- Update binaries and docs to install and package
- Fix changelog

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.8a-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Mar 01 2015 Adam Huffman <bloch@verdurin.com> - 1.0.8a-1
- Update to new Github-based upstream release
- Add armadillo BR

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.9.18-14
- Rebuild for boost 1.57.0

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.18-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.18-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.9.18-11
- Rebuild for boost 1.55.0

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 0.9.18-10
- rebuild for boost 1.55.0

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.18-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 0.9.18-8
- Rebuild for boost 1.54.0

* Thu Jul 18 2013 Petr Pisar <ppisar@redhat.com> - 0.9.18-7
- Perl 5.18 rebuild

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.9.18-6
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.9.18-5
- Rebuild for Boost-1.53.0

* Sun Aug 12 2012 Kevin Fenzi <kevin@scrye.com> - 0.9.18-4
- Rebuild for new boost

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.18-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.18-2
- Rebuilt for c++ ABI breakage

* Wed Jan 11 2012 Adam Huffman <verdurin@fedoraproject.org> - 0.9.18-1
- update to 0.9.18
- remove pileup.sh and get_isize.rb, discarded upstream
- update patches and remove flags patch

* Sun Nov 20 2011 Adam Huffman <adam@vaioz.verdurin.salon> - 0.9.14-2
- rebuild for new Boost in Rawhide

* Fri Oct  7 2011 Adam Huffman <bloch@verdurin.com> - 0.9.14-1
- new upstream bugfix release

* Wed Aug 17 2011 Adam Huffman <bloch@verdurin.com> - 0.9.12-1
- upstream release 0.9.12 fixing a possible segfault

* Thu Jul 21 2011 Adam Huffman <bloch@verdurin.com> - 0.9.11-2
- rebuild for new Boost in Rawhide

* Sat May 28 2011 Adam Huffman <bloch@verdurin.com> - 0.9.11-1
- new upstream release
- add routeB.sh script
- sam2hits.rb removed

* Fri May 27 2011 Adam Huffman <bloch@verdurin.com> - 0.9.10b-3
- patch to deal with zlib better

* Sun May 15 2011 Adam Huffman <bloch@verdurin.com> - 0.9.10b-2
- remove bundled binaries
- remove VERSION
- explicit naming for included scripts

* Sun May  8 2011 Adam Huffman <bloch@verdurin.com> - 0.9.10b-1
- new upstream version
- patch descriptions

* Sun May  8 2011 Adam Huffman <bloch@verdurin.com> - 0.9.9-3
- fix permissions for installed files
- include missing Perl script
- improve description

* Sat Apr  9 2011 Adam Huffman <bloch@verdurin.com> - 0.9.9-2
- fix compilation flags for debuginfo
- include shell and Ruby scripts

* Mon Apr  4 2011 Adam Huffman <bloch@verdurin.com> - 0.9.9-1
- initial version
